@@ -18,14 +18,28 @@ class Aircraft:
             self.base_longitude = base_longitude
             self.augment_aircraft_list()
             self.set_nearest_aircraft()
-    
+
 
     def augment_aircraft_list(self):
+        """
+        Adds additional options to the aircraft list and sets it as the new `aircraft_list`.
+        This method does not exist as part of init, so that it can be called separately by whatever has instantiated the
+        Aircraft class
+        """
         aircraft_list = self.add_aircraft_options()
         self.aircraft_list = aircraft_list
-    
+
 
     def set_nearest_aircraft(self):
+        """
+        Sets the nearest aircraft to the current location and adds links to various databases.
+
+        The function creates a copy of the first aircraft in the aircraft list, adds links to the HEXDB and ADSB databases,
+        and sets the result as the nearest aircraft.
+
+        Returns:
+            None
+        """
         # dict creates a copy of the dictionary. aircraft_list remains unaffected.
         nearest_aircraft = dict(self.aircraft_list[0])
         icao_24 = nearest_aircraft['icao']
@@ -39,9 +53,13 @@ class Aircraft:
         }
 
         self.nearest_aircraft = nearest_aircraft
-    
+
 
     def retrieve_external_aircraft_options(self):
+        """
+        Retrieves external flight information and aircraft image for the nearest aircraft.
+        Then updates the `nearest_aircraft` dictionary with the aircraft image URL and the merged flight information.
+        """
         nearest_aircraft = self.nearest_aircraft
         icao_24 = nearest_aircraft['icao_24']
         aircraft_image = Aircraft.get_aircraft_image(icao_24)
@@ -49,21 +67,25 @@ class Aircraft:
         adsb_db_options = Aircraft.get_adsb_db_flight(icao_24)
 
         flight_options = {}
-        if (adsb_db_options):
+        if adsb_db_options:
             flight_options = adsb_db_options
-        elif (hex_db_options):
+        elif hex_db_options:
             flight_options= hex_db_options
 
         nearest_aircraft.update(flight_options)
         nearest_aircraft['image'] = aircraft_image
 
         if ('flightaware' in nearest_aircraft and bool(nearest_aircraft['flightaware'])):
-            nearest_aircraft['flightaware']['live_url'] = f"https://flightaware.com/live/flight/{flight_options['registration']}"
+            live_url = f"https://flightaware.com/live/flight/{flight_options['registration']}"
+            nearest_aircraft['flightaware']['live_url'] = live_url
 
         self.nearest_aircraft = nearest_aircraft
 
-    
+
     def map_static_aircraft_options(self, stored_aircraft):
+        """
+        Maps static aircraft information from a stored aircraft dictionary to the nearest aircraft dictionary.
+        """
         keys_to_map = [
             'country_iso',
             'country_name',
@@ -81,57 +103,58 @@ class Aircraft:
             self.nearest_aircraft[key] = stored_aircraft[key]
 
 
-    def get_aircraft_list(self, filter_aircraft = True):
+    def get_aircraft_list(self):
         """
         Get the aircraft messages and returns as list
         """
         aircraft_url = f'{self.base_adsb_url}/data/aircraft.json'
         json_obj = requests_utils.get_api(aircraft_url)
-        result = json_obj
-
-        if (filter_aircraft):
-            result = [
-                d for d in json_obj['aircraft']
-                if "lat" in d and "lon" in d and d["lat"] is not None and d["lon"] is not None
-            ]
+        result = json_obj['aircraft']
 
         return result
-    
+
 
     def add_aircraft_options(self):
         """
         Adds additional data to aircraft based on aircraft properties
         """
+        print(self.aircraft_list)
         aircraft_list_with_options = []
         for aircraft in self.aircraft_list:
-            new_aircraft = aircraft.copy()
-            aircraft_lat = new_aircraft['lat']
-            aircraft_lon = new_aircraft['lon']
+            print('asgawegaweg')
+            print(aircraft)
+            if Aircraft.get_has_coordinates(aircraft):
+                new_aircraft = aircraft.copy()
+                aircraft_lat = new_aircraft['lat']
+                aircraft_lon = new_aircraft['lon']
 
-            distance = Aircraft.calculate_distance(
-                self.base_latitude, self.base_longitude, aircraft_lat, aircraft_lon
-            )
-            degrees, direction = Aircraft.get_direction(
-                self.base_latitude, self.base_longitude, aircraft_lat, aircraft_lon
-            )
+                distance = Aircraft.calculate_distance(
+                    self.base_latitude, self.base_longitude, aircraft_lat, aircraft_lon
+                )
+                degrees, direction = Aircraft.get_direction(
+                    self.base_latitude, self.base_longitude, aircraft_lat, aircraft_lon
+                )
 
-            new_aircraft['distance'] = distance
-            new_aircraft['degrees'] = degrees
-            new_aircraft['direction'] = direction
-            new_aircraft['icao'] = aircraft['hex']
-            new_aircraft['icao_24'] = aircraft['hex']
+                new_aircraft['distance'] = distance
+                new_aircraft['degrees'] = degrees
+                new_aircraft['direction'] = direction
+                new_aircraft['icao'] = aircraft['hex']
+                new_aircraft['icao_24'] = aircraft['hex']
 
-            redirect_url = f"https://flightaware.com/live/modes/{aircraft['hex']}/redirect"
-            if ('flight' in aircraft and bool(aircraft['flight'])):
-                redirect_url = f"https://flightaware.com/live/modes/{aircraft['hex']}/ident/{aircraft['flight']}/redirect"
+                mode_s = aircraft['hex']
+                redirect_url = f"https://flightaware.com/live/modes/{mode_s}/redirect"
+                if ('flight' in aircraft and bool(aircraft['flight'])):
+                    redirect_url = f"https://flightaware.com/live/modes/{mode_s}/ident/{aircraft['flight']}/redirect"
 
-            new_aircraft['flightaware'] = {
-                'redirect_url': redirect_url
-            }
+                new_aircraft['flightaware'] = {
+                    'redirect_url': redirect_url
+                }
 
-            aircraft_list_with_options.append(new_aircraft)
+                aircraft_list_with_options.append(new_aircraft)
+            else:
+                aircraft_list_with_options.append(aircraft)
 
-        return sorted(aircraft_list_with_options, key=lambda x: x["distance"])
+        return Aircraft.sort_by_distance(aircraft_list_with_options)
 
 
     @staticmethod
@@ -155,7 +178,7 @@ class Aircraft:
             'registration': 'Registration',
             'type': 'Type'
         }
-        
+
         return requests_utils.map_keys(hex_db_obj, mapped_keys)
 
 
@@ -179,8 +202,18 @@ class Aircraft:
             'registration': 'registration',
             'type': 'type'
         }
-        
+
         return requests_utils.map_keys(adsb_aircraft, mapped_keys)
+    
+
+    @staticmethod
+    def get_has_coordinates(aircraft = {}) -> bool:
+        """
+        Determine whether an aircraft has coordinates
+        """
+        print('aircraft')
+        print(aircraft)
+        return True if aircraft.get("lat") is not None and aircraft.get("lon") is not None else False
 
 
     @staticmethod
@@ -232,12 +265,12 @@ class Aircraft:
         # Haversine formula
         dlat = lat2 - lat1
         dlon = lon2 - lon1
-        a = math.sin(dlat/2)**2 + math.cos(lat1) * math.cos(lat2) * math.sin(dlon/2)**2
-        c = 2 * math.atan2(math.sqrt(a), math.sqrt(1-a))
-        distance = EARTH_RADIUS_KM * c
+        square_half_chord = math.sin(dlat/2)**2 + math.cos(lat1) * math.cos(lat2) * math.sin(dlon/2)**2
+        angular_distance = 2 * math.atan2(math.sqrt(square_half_chord), math.sqrt(1-square_half_chord))
+        distance = EARTH_RADIUS_KM * angular_distance
 
         return distance
-    
+
 
     @staticmethod
     def get_direction(base_lat, base_lon, dest_lat, dest_lon):
@@ -258,3 +291,25 @@ class Aircraft:
         direction = directions[idx]
 
         return degrees, direction
+    
+
+    @staticmethod
+    def sort_by_distance(data):
+        """
+        Sort a list of dictionaries based on their "distance" values, with dictionaries that have a defined
+        "distance" value appearing first.
+        """
+        # Split dictionaries into those with a distance key and those without
+        with_distance = []
+        without_distance = []
+        for d in data:
+            if "distance" in d:
+                with_distance.append(d)
+            else:
+                without_distance.append(d)
+
+        # Sort dictionaries with distance by their distance values
+        with_distance_sorted = sorted(with_distance, key=lambda x: x.get("distance", float("inf")))
+
+        # Combine the two lists, with dictionaries with distance at the beginning
+        return with_distance_sorted + without_distance
